@@ -8,12 +8,12 @@ use vars qw($VERSION);
 
 BEGIN
 {
-    $VERSION = '1.0';
+    $VERSION = '1.01';
   }
 
 
 use Class::MethodMaker
-    [ scalar => [qw/ datetime1 datetime2 worktiming weekends holidayfile /],
+    [ scalar => [qw/ datetime1 datetime2 worktiming weekends holidayfile holidays /],
     
     ];
 
@@ -25,8 +25,9 @@ sub new
     my $datetime2 = $args{datetime2} || die "datetime2 parameter required";
     my $worktiming = $args{worktiming} || [9,18];
     my $weekends = $args{weekends} || [6,7];
+    my $holidays = $args{holidays} || "" ;
     my $holidayfile = $args{holidayfile} || "";
-    return bless {datetime1=>$datetime1,datetime2=>$datetime2,worktiming=>$worktiming,weekends=>$weekends,holidayfile=>$holidayfile} , $self;
+    return bless {datetime1=>$datetime1,datetime2=>$datetime2,worktiming=>$worktiming,weekends=>$weekends,holidays=>$holidays,holidayfile=>$holidayfile} , $self;
     
     
   }
@@ -65,12 +66,12 @@ sub getdays
 	}
       }
       # Read company holiday's from the file 
-      if ($self->{holidayfile}) {
+      if ($self->holidayfile) {
 	open(HF , $self->holidayfile) || warn "Predinfed holiday file not found";
 	#exclude any holidays that have been marked in the companies academic year
 	forHF: foreach(<HF>)
 	  {
-	    my ($day , $month , $year) = split('-',$_);
+	    my ($year , $month , $day) = split('-',$_);
 	    my $holidate = DateTime->new(year=>$year,month=>$month,day=>$day);
 	    #check if mentioned holiday lies in defined weekend , shouldnt deduct twice
 	    foreach (@{$self->weekends}) {
@@ -85,10 +86,37 @@ sub getdays
 
 
 	  }
+      }
+      
+	#added to the new release to also allow holidays as reference needs testing 
+	if ($self->holidays) {
+	  my $holidays = $self->holidays;
+	  
+	forHS: foreach(@$holidays)
+	    {
+	      my ($year , $month , $day) = split('-',$_);
+	      my $holidate = DateTime->new(year=>$year,month=>$month,day=>$day);
+	      #check if mentioned holiday lies in defined weekend , shouldnt deduct twice
+	      foreach (@{$self->weekends}) {
+		if ($holidate->day_of_week==$_) {
+		  last forHS 
+		}
+		if (dateinbetween($holidate)) {
+		  $days = $days - 1;
+		
+		}
+	      }
+
+
+	    }
+
+
       }      
       return $days;
       
-}
+  }          
+      
+      
     
 sub gethours 
       {
@@ -185,9 +213,10 @@ BusinessHours - An object that calculates business days and hours
                                   datetime2=>$datetime2,
                                   worktiming=>[9,18], # 9 am to 6 om
                                   weekends=>[6,7], #saturday , sunday
+                                  holidays=>["2007-10-31",2007-12-24]
                                   holidayfile=>'holidaylist' #holidaylist is a text file 
                                                              #with each date in a new line
-                                                             #in the format dd-mm-yyyy  
+                                                             #in the format yyyy-mm-dd  
                                  );
 
   print $testing->getdays."\n"; # the total business days 
@@ -218,6 +247,7 @@ This class method accepts the following parameters in the hash format.
                              Defaults to [9,18] 
             weekends     =>  A list reference with values of the days that must be considered 
                              as non-working in a week.Defaults to [6,7] - Saturday , Sunday.
+            holidays     =>  A list reference with holiday dates.
             holidayfile  =>  The name of a file from which predefined holidays can be excluded
                              from business days /hours calculation. Defaults to no file.
 
